==> owncloud-8.1.0p2.tgz: owncloud/apps/updater/l10n/gl.js <==
OC.L10N.register(
    "updater",
    {
    "Version not found" : "Non se atopa a versión",
    "Upgrade is not possible. Your web server does not have permission to remove the following directory:" : "Non é posíbel a anovación. O servidor web non ten permiso para eliminar o seguinte directorio:",
    "Update permissions on this directory and its content or remove it manually first." : "Actualice os permisos deste directorio e o seu contido ou retíreo manualmente antes.",
    "Unable to switch channel." : "Non é posíbel cambiar a canle.",
    "Update failed." : "Non foi posíbel facer a actualización.",
    "Fetching..." : "Obtendo...",
    "<strong>The update was unsuccessful.</strong><br />Please check logs at admin page and report this issue to the <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">ownCloud community</a>." : "<strong>A actualización non foi satisfactoria.</strong><br />Revise os rexistros na páxina de administración e informe desta incidencia á <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">comunidade ownCloud</a>.",
    "<strong>Server error.</strong> Please check web server log file for details" : "<strong>Produciuse un erro no servidor.</strong>Revise o ficheiro de rexistro do servidor web para obter máis detalles",
    "Retry" : "Tentar de novo",
    "Here is your backup:" : "A súa copia de seguranza está aquí:",
    "Proceed" : "Proceder",
    "<strong>All done.</strong> Click to the link below to start database upgrade." : "<strong>Todo feito.</strong> Prema na ligazón inferior para comezar a anovar a base de datos.",
    "Production" : "Produción",
    "Stable" : "Estábel",
    "Beta" : "Beta",
    "Daily" : "Diario",
    "Please ask your server administrator to enable PHP zip extension." : "Pídalle ao seu administrador de sistemas que active a extensión PHP zip.",
    "Not possible to update %s to %s. Downgrading or skipping major releases is not supported." : "Non é posible actualizar %s a %s. Non están admitidas as regresións ou a omisión de edicións maiores.",
    "Make sure that your web server has read access to the following files and directories:" : "Asegúrese de que o seu servidor web ten acceso de lectura aos seguintes ficheiros e directorios:",
    "Make sure that your web server has write access to the following files and directories:" : "Asegúrese de que o seu servidor web ten acceso de escritura aos seguintes ficheiros e directorios:",
    "Updates" : "Actualizacións",
    "<strong>A new version is available: {{newVersion}}</strong>" : "<strong>Hai unha nova versión dispoñíbel: {{newVersion}}</strong>",
    "Updates will be available in the updater app and ownCloud admin panel within a few days of an update announcement." : "As actualizacións estarán dispoñíbeis na aplicación de actualización e no panel de administración do ownCloud aos poucos días de seren anunciada a actualización.",
    "<strong>Up to date.</strong> <em>Checked on {{checkedAt}}</em>" : "<strong>Actualizado.</strong> <em>Comprobado o {{checkedAt}}</em>",
    "1. Check & Backup" : "1. Comprobar e facer unha copia de seguranza",
    "2. Download & Extract" : "2. Descargar e extraer",
    "3. Replace" : "3. Substituír",
    "Update" : "Actualizar",
    "Update channel:" : "Canle de actualización:",
    "Please note update is possible only to a version that is greater than the one currently installed. If you upgraded from a less stable channel you will be able to upgrade from a more stable channel only after the version that is greater than you installed reaches it." : "Teña en conta que só é posíbel actualizar a unha versión máis recente que a actualmente instalada. Se actualizou desde unha canle menos estábel poderá actualizar desde unha canle máis estábel só após que a versión que ten instalada sexa acadada por esa canle máis estábel.",
    "Updater-Backups" : "Copias de seguridade do actualizador",
    "Note" : "Nota",
    "Here you can find backups of the core of your ownCloud <strong>(excluding your data)</strong> after starting an update to a newer version." : "Aquí pode atopar copias de seguridade do núcleo do ownCloud <strong>(excluíndo os datos)</strong> tras iniciar unha actualización a unha nova versión.",
    "<strong>Please always backup your data separately before updating!</strong>" : "<strong>Faga sempre unha copia de seguridade dos seus datos de xeito separado antes de actualizar!</strong>",
    "Backup directory" : "Directorio das copias de seguranza",
    "No backups found." : "Non se atoparon copias de seguridade.",
    "Backup" : "Copia de seguranza",
    "Done on" : "Feito o",
    "Size" : "Tamaño",
    "Download" : "Descargar",
    "Delete" : "Eliminar",
    "Are you sure you want to delete {{entry.title}}" : "Confirma que quere eliminar {{entry.title}}?"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/updater/l10n/gl.js <==
OC.L10N.register(
    "updater",
    {
    "Unable to switch channel." : "Non é posíbel cambiar a canle.",
    "Version not found" : "Non se atopa a versión",
    "Upgrade is not possible. Your web server does not have permission to remove the following directory:" : "Non é posíbel a anovación. O servidor web non ten permiso para eliminar o seguinte directorio:",
    "Update permissions on this directory and its content or remove it manually first." : "Actualice os permisos deste directorio e o seu contido ou retíreo manualmente antes.",
    "Update failed." : "Non foi posíbel facer a actualización.",
    "Fetching..." : "Obtendo...",
    "Retry" : "Tentar de novo",
    "Here is your backup:" : "A súa copia de seguranza está aquí:",
    "Proceed" : "Proceder",
    "<strong>All done.</strong> Click to the link below to start database upgrade." : "<strong>Todo feito.</strong> Prema na ligazón inferior para comezar a anovar a base de datos.",
    "Production" : "Produción",
    "Stable" : "Estábel",
    "Beta" : "Beta",
    "Daily" : "Diario",
    "Please ask your server administrator to enable PHP zip extension." : "Pídalle ao seu administrador de sistemas que active a extensión PHP zip.",
    "Not possible to update %s to %s. Downgrading or skipping major releases is not supported." : "Non é posible actualizar %s a %s. Non están admitidas as regresións ou a omisión de edicións maiores.",
    "Make sure that your web server has read access to the following files and directories:" : "Asegúrese de que o seu servidor web ten acceso de lectura aos seguintes ficheiros e directorios:",
    "Make sure that your web server has write access to the following files and directories:" : "Asegúrese de que o seu servidor web ten acceso de escritura aos seguintes ficheiros e directorios:",
    "Updates" : "Actualizacións",
    "<strong>A new version is available: {{newVersion}}</strong>" : "<strong>Hai unha nova versión dispoñíbel: {{newVersion}}</strong>",
    "1. Check & Backup" : "1. Comprobar e facer unha copia de seguranza",
    "2. Download & Extract" : "2. Descargar e extraer",
    "3. Replace" : "3. Substituír",
    "Update" : "Actualizar",
    "Update channel:" : "Canle de actualización:",
    "Updater-Backups" : "Copias de seguridade do actualizador",
    "No backups found." : "Non se atoparon copias de seguridade.",
    "Backup" : "Copia de seguranza",
    "Done on" : "Feito o",
    "Size" : "Tamaño",
    "Download" : "Descargar",
    "Delete" : "Eliminar",
    "Are you sure you want to delete {{entry.title}}" : "Confirma que quere eliminar {{entry.title}}?",
    "Backup directory" : "Directorio das copias de seguranza"
},
"nplurals=2; plural=(n != 1);");
